@@ -32,11 +32,9 @@
 /*******************************************************************************/
 #include "weather-common.h"
 /*******************************************************************************/
-extern	WeatherSource	weather_sources[];
-/*******************************************************************************/
-GtkWidget* create_sun_time_widget(GSList *day);
-GtkWidget* create_moon_phase_widget(GSList *current);
-GtkWidget* create_time_updates_widget(GSList *current, gboolean change_color);
+GtkWidget* create_sun_time_widget(GHashTable *day);
+GtkWidget* create_moon_phase_widget(GHashTable *current);
+GtkWidget* create_time_updates_widget(GHashTable *current, gboolean change_color);
 
 gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event, gpointer user_data);
 
@@ -51,9 +49,9 @@ void popup_close_button_handler(GtkWidget *button, GdkEventButton *event,
 void maximize_button_handler(GtkWidget *button, GdkEventButton *event, gpointer user_data);
 void destroy_container (GtkWidget *widget, gpointer *data);
 
-GtkWidget* create_day_tab(GSList *current, GSList *day, gchar **day_name);
-GtkWidget* create_pseudo_day_tab(GSList *current, GSList *day, gchar **day_name);
-GtkWidget* create_current_tab(GSList *current);
+GtkWidget* create_day_tab(GHashTable *current, GHashTable *day, gchar **day_name);
+GtkWidget* create_pseudo_day_tab(GHashTable *current, GHashTable *day, gchar **day_name);
+GtkWidget* create_current_tab(GHashTable *current);
 GtkWidget* create_hour_tab(void);
 GtkWidget* create_toolbar_box(GtkCallback exit_function, GtkWidget *window, gboolean fullscreen_button);
 gboolean make_current_tab(GtkWidget *vbox);
@@ -65,24 +63,6 @@ void popup_switch_cb(GtkNotebook * nb, gpointer nb_page, gint page, gpointer dat
 #ifdef CLUTTER
 void popup_window_expose(GtkWidget *widget, GdkEventExpose *event);
 #endif
-void destroy_popup_window(void);
-/*******************************************************************************/
-extern void weather_window_settings(GtkWidget *widget,
-				    gpointer user_data);
-/*extern void pre_update_weather(void);*/
-extern void update_weather(gboolean show_update_window);
-extern void set_font(GtkWidget *widget, const gchar *description, const gint size);
-extern void set_font_color (GtkWidget *widget, guint16 red, guint16 green, guint16 blue);
-extern float c2f(float temp);
-extern void swap_temperature(int *hi, int *low);
-extern gpointer hash_table_find(gpointer key, gboolean search_short_name);
-extern float convert_wind_units(int to, float value);
-extern GtkWidget* create_button_with_image(const char *path, const char *image_name,
-			int image_size, gboolean with_border, gboolean toggled);
-extern void create_about_dialog(void);  /* create help dialog */
-extern gboolean change_station_prev(GtkWidget *widget, GdkEvent *event,
-                    		    gpointer user_data);
-extern gboolean change_station_next(GtkWidget *widget, GdkEvent *event,
-                    		    gpointer user_data);
+void destroy_popup_window(gpointer user_data);
 /*******************************************************************************/
 #endif
